@@ -49,7 +49,12 @@ class BlockParser:
         if block["type"] == 'child_page':
             return None
 
-        # 指定类型才递归
+        # 递归黑名单
+        if block["type"] == "template":
+            common_op.debug_log("type " + block["type"] + " has no child, ignore", level=NotionDump.DUMP_MODE_DEFAULT)
+            return None
+
+        # 指定类型才递归(白名单)
         if block["type"] != "to_do" \
                 and block["type"] != "numbered_list_item" \
                 and block["type"] != "bulleted_list_item" \
@@ -61,7 +66,8 @@ class BlockParser:
                 and block["type"] != "synced_block" \
                 and block["type"] != "heading_1" \
                 and block["type"] != "heading_2" \
-                and block["type"] != "heading_3":
+                and block["type"] != "heading_3" \
+                and block["type"] != "paragraph":
             common_op.debug_log("[ISSUE] type " + block["type"] + " has no child", level=NotionDump.DUMP_MODE_DEFAULT)
             return None
 
@@ -77,6 +83,7 @@ class BlockParser:
         if len(block_list) == 0:
             return None
         # 返回获取到的块列表
+        common_op.debug_log("## retrieve block " + block_id, level=NotionDump.DUMP_MODE_DEFAULT)
         return block_list
 
     def parser_block(self, block, list_index, last_line_is_table):
@@ -147,9 +154,20 @@ class BlockParser:
         elif block_type == "bookmark":
             # Page bookmark
             block_text = self.base_parser.bookmark_parser(block, self.parser_type)
+        elif block_type == "link_preview":
+            # Page bookmark
+            block_text = self.base_parser.link_preview_parser(block, self.parser_type)
         elif block_type == "link_to_page":
             # Page link_to_page
             block_text = self.base_parser.link_to_page_parser(block, self.parser_type)
+        elif block_type == "table_of_contents":
+            block_text = '[TOC]'
+        elif block_type == "template":
+            # 模板内容不解析
+            block_text = ''
+        elif block_type == "breadcrumb":
+            # 路径信息不解析（notion也不会返回）
+            block_text = ''
         else:
             common_op.debug_log("[ISSUE] unknown page block properties type:" + block_type, level=NotionDump.DUMP_MODE_DEFAULT)
         return block_text
@@ -211,8 +229,11 @@ class BlockParser:
                 # 看改块下面有没有子块，如果有就继续解析
                 children_block_list = self.__get_children_block_list(block)
                 if children_block_list is not None:
-                    if block_type == "heading_1" or block_type == "heading_2" or block_type == "heading_3":
-                        # 不需要收缩indent值
+                    if block_type == "heading_1" \
+                            or block_type == "heading_2" \
+                            or block_type == "heading_3" \
+                            or block_type == "paragraph":
+                        # 不需要加大indent值
                         block_text += "\n"
                         block_text += self.parser_block_list(children_block_list, indent)
                     else:
