@@ -11,7 +11,7 @@ from NotionDump.utils import common_op
 
 TOKEN_TEST = "secret_g6easunNXs3S5OdTS4qBhlPZN9fjxTkdJ80wOImK5cZ"
 PAGE_MIX_ID = "ed0a3b0f57b34712bc6bafcbdb413d50"
-NotionDump.DUMP_MODE = NotionDump.DUMP_MODE_DEBUG
+# NotionDump.DUMP_MODE = NotionDump.DUMP_MODE_DEBUG
 
 
 # 解析数据库内容测试：根据token和id解析数据库内容，得到临时CSV文件
